@@ -1,3 +1,4 @@
+import builtins
 import datetime
 from files_sdk.api import Api
 from files_sdk.list_obj import ListObj
@@ -13,6 +14,7 @@ class Behavior:
         'description': None,     # string - Description for this behavior.
         'value': None,     # object - Settings for this behavior.  See the section above for an example value to provide here.  Formatting is different for each Behavior type.  May be sent as nested JSON or a single JSON-encoded string.  If using XML encoding for the API call, this data must be sent as a JSON-encoded string.
         'attachment_file': None,     # file - Certain behaviors may require a file, for instance, the "watermark" behavior requires a watermark image
+        'attachment_delete': None,     # boolean - If true, will delete the file stored in attachment
     }
 
     def __init__(self, attributes=None, options=None):
@@ -37,6 +39,7 @@ class Behavior:
     #   description - string - Description for this behavior.
     #   behavior - string - Behavior type.
     #   path - string - Folder behaviors path.
+    #   attachment_delete - boolean - If true, will delete the file stored in attachment
     def update(self, params = None):
         if not isinstance(params, dict):
             params = {}
@@ -88,15 +91,15 @@ class Behavior:
             self.set_attributes(new_obj.get_attributes())
 
 # Parameters:
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `behavior`.
-#   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `behavior`.
-#   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `behavior`.
-#   filter_gteq - object - If set, return records where the specifiied field is greater than or equal to the supplied value. Valid fields are `behavior`.
-#   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `behavior`.
-#   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `behavior`.
-#   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `behavior`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `behavior`.
+#   filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `behavior`.
+#   filter_gteq - object - If set, return records where the specified field is greater than or equal to the supplied value. Valid fields are `behavior`.
+#   filter_like - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `behavior`.
+#   filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `behavior`.
+#   filter_lteq - object - If set, return records where the specified field is less than or equal to the supplied value. Valid fields are `behavior`.
 #   behavior - string - If set, only shows folder behaviors matching this behavior type.
 def list(params = None, options = None):
     if not isinstance(params, dict):
@@ -147,15 +150,15 @@ def get(id, params = None, options = None):
     find(id, params, options)
 
 # Parameters:
-#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via the X-Files-Cursor-Next header.
+#   cursor - string - Used for pagination.  Send a cursor value to resume an existing list from the point at which you left off.  Get a cursor from an existing list via either the X-Files-Cursor-Next header or the X-Files-Cursor-Prev header.
 #   per_page - int64 - Number of records to show per page.  (Max: 10,000, 1,000 or less is recommended).
 #   sort_by - object - If set, sort records by the specified field in either 'asc' or 'desc' direction (e.g. sort_by[last_login_at]=desc). Valid fields are `behavior`.
-#   filter - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `behavior`.
-#   filter_gt - object - If set, return records where the specifiied field is greater than the supplied value. Valid fields are `behavior`.
-#   filter_gteq - object - If set, return records where the specifiied field is greater than or equal to the supplied value. Valid fields are `behavior`.
-#   filter_like - object - If set, return records where the specifiied field is equal to the supplied value. Valid fields are `behavior`.
-#   filter_lt - object - If set, return records where the specifiied field is less than the supplied value. Valid fields are `behavior`.
-#   filter_lteq - object - If set, return records where the specifiied field is less than or equal to the supplied value. Valid fields are `behavior`.
+#   filter - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `behavior`.
+#   filter_gt - object - If set, return records where the specified field is greater than the supplied value. Valid fields are `behavior`.
+#   filter_gteq - object - If set, return records where the specified field is greater than or equal to the supplied value. Valid fields are `behavior`.
+#   filter_like - object - If set, return records where the specified field is equal to the supplied value. Valid fields are `behavior`.
+#   filter_lt - object - If set, return records where the specified field is less than the supplied value. Valid fields are `behavior`.
+#   filter_lteq - object - If set, return records where the specified field is less than or equal to the supplied value. Valid fields are `behavior`.
 #   path (required) - string - Path to operate on.
 #   recursive - string - Show behaviors above this path?
 #   behavior - string - DEPRECATED: If set only shows folder behaviors matching this behavior type. Use `filter[behavior]` instead.
@@ -258,6 +261,7 @@ def webhook_test(params = None, options = None):
 #   description - string - Description for this behavior.
 #   behavior - string - Behavior type.
 #   path - string - Folder behaviors path.
+#   attachment_delete - boolean - If true, will delete the file stored in attachment
 def update(id, params = None, options = None):
     if not isinstance(params, dict):
         params = {}
@@ -274,8 +278,10 @@ def update(id, params = None, options = None):
         raise InvalidParameterError("Bad parameter: description must be an str")
     if "behavior" in params and not isinstance(params["behavior"], str):
         raise InvalidParameterError("Bad parameter: behavior must be an str")
-    if "path" in params and not isinstance(params["path"], (str, int, dict)): 
-        raise InvalidParameterError("Bad parameter: path must be one of str, int, dict")
+    if "path" in params and not isinstance(params["path"], str):
+        raise InvalidParameterError("Bad parameter: path must be an str")
+    if "attachment_delete" in params and not isinstance(params["attachment_delete"], (str, int, dict)): 
+        raise InvalidParameterError("Bad parameter: attachment_delete must be one of str, int, dict")
     if "id" not in params:
         raise MissingParameterError("Parameter missing: id")
     response, options = Api.send_request("PATCH", "/behaviors/{id}".format(id=params['id']), params, options)
